DestructDrop

Trait DestructDrop 

pub trait DestructDrop {
    // Required method
    fn destruct_drop(self);
}
Trait for consuming a struct or enum without dropping it while dropping all of its contents normally.

Required Methods

fn destruct_drop(self)

Consume self without dropping it while dropping all of its contents normally.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors